| Examp1.3.2 | R Documentation |
Examp1.3.2 is used for inspecting probability distribution and to define a plausible process through linear models and generalized linear models.
Muhammad Yaseen (myaseen208@gmail.com)
Duchateau, L. and Janssen, P. and Rowlands, G. J. (1998).Linear Mixed Models. An Introduction with applications in Veterinary Research. International Livestock Research Institute.
ex124
#-------------------------------------------------------------
## Example 1.3.2 p-16
#-------------------------------------------------------------
# PROC GLM DATA=ex124;
# CLASS herd dose drug;
# MODEL PCVdif=drug herd(drug) dose dose*drug;
# RANDOM herd(drug);
# RUN;
str(ex124)
summary(ex124)
ex124$herd1 <- factor(ex124$herd)
ex124$drug1 <- factor(ex124$drug)
ex124$dose1 <- factor(ex124$dose)
fm1.1 <-
aov(
formula = PCVdif ~ drug1 + Error(herd1:drug1) + dose1 + dose1:drug1
, data = ex124
, projections = FALSE
, qr = TRUE
, contrasts = NULL
# , ...
)
if (requireNamespace("report", quietly = TRUE)) {
fm1.1 |>
report::report()
}
summary(fm1.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.