| Examp2.4.3.1 | R Documentation |
Examp2.4.3.1 is used for inspecting probability distribution and to define a plausible process through linear models and generalized linear models.
Muhammad Yaseen (myaseen208@gmail.com)
Duchateau, L. and Janssen, P. and Rowlands, G. J. (1998).Linear Mixed Models. An Introduction with applications in Veterinary Research. International Livestock Research Institute.
ex124
#-------------------------------------------------------------
## Example 2.4.3.1 p-66
#-------------------------------------------------------------
# PROC MIXED DATA=ex127;
# CLASS sire;
# MODEL ww=;
# RANDOM sire/solution;
# RUN;
str(ex127)
if (requireNamespace("lme4", quietly = TRUE)) {
fm2.8 <-
lme4::lmer(
formula = Ww ~ (1 | sire)
, data = ex127
, REML = TRUE
, control = lme4::lmerControl()
, start = NULL
, verbose = 0L
, contrasts = NULL
, devFunOnly = FALSE
)
if (requireNamespace("report", quietly = TRUE)) {
fm2.8 |>
report::report()
}
summary(fm2.8)
lme4::fixef(fm2.8)
lme4::ranef(fm2.8)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.