| Examp2.5.1.1 | R Documentation |
Examp2.5.1.1 is used for inspecting probability distribution and to define a plausible process through linear models and generalized linear models.
Muhammad Yaseen (myaseen208@gmail.com)
Duchateau, L. and Janssen, P. and Rowlands, G. J. (1998).Linear Mixed Models. An Introduction with applications in Veterinary Research. International Livestock Research Institute.
ex124
#-------------------------------------------------------------
## Example 2.5.1.1 p-67
#-------------------------------------------------------------
# PROC MIXED DATA=ex125;
# CLASS drug dose region;
# MODEL pcv=drug dose drug*dose / solution covb;
# RANDOM region drug*region;
# RUN;
str(ex125)
if (requireNamespace("lme4", quietly = TRUE)) {
fm2.9 <-
lme4::lmer(
formula = Pcv ~ dose * Drug + (1 | Region / Drug)
, data = ex125
, REML = TRUE
, control = lme4::lmerControl()
, start = NULL
, verbose = 0L
, contrasts = list(dose = "contr.SAS", Drug = "contr.SAS")
, devFunOnly = FALSE
)
if (requireNamespace("report", quietly = TRUE)) {
fm2.9 |>
report::report()
}
if (requireNamespace("emmeans", quietly = TRUE)) {
emm2.9 <- emmeans::emmeans(fm2.9, ~ dose | Drug, lmer.df = "asymptotic")
print(emm2.9)
print(emmeans::contrast(emm2.9, method = "pairwise"))
}
summary(fm2.9)
anova(fm2.9)
summary(fm2.9)$vcov
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.