Learn R Programming

VetResearchLMM (version 1.1.0)

Examp2.4.2.2: Examp2.4.2.2 from Duchateau, L. and Janssen, P. and Rowlands, G. J. (1998).Linear Mixed Models. An Introduction with applications in Veterinary Research. International Livestock Research Institute.

Description

Examp2.4.2.2 is used for inspecting probability distribution and to define a plausible process through linear models and generalized linear models.

Arguments

Author

  1. Muhammad Yaseen (myaseen208@gmail.com)

References

  1. Duchateau, L. and Janssen, P. and Rowlands, G. J. (1998).Linear Mixed Models. An Introduction with applications in Veterinary Research. International Livestock Research Institute.

See Also

ex124

Examples

Run this code
#-------------------------------------------------------------
## Example 2.4.2.2 p-64
#-------------------------------------------------------------
# PROC MIXED DATA=ex125 METHOD=ML;
# CLASS drug dose region;
# MODEL pcv=drug dose drug*dose;
# RANDOM region drug*region;
# RUN;
# 
# PROC MIXED DATA=ex125 METHOD=REML;
# CLASS drug dose region;
# MODEL pcv=drug dose drug*dose;
# RANDOM region drug*region;
# RUN;
 
 
# \donttest{
str(ex125)
if (requireNamespace("lme4", quietly = TRUE)) {
  fm2.4 <-
    lme4::lmer(
           formula    = Pcv ~ dose * Drug + (1 | Region / Drug)
         , data       = ex125
         , REML       = FALSE
         , control    = lme4::lmerControl()
         , start      = NULL
         , verbose    = 0L
         , contrasts  = NULL
         , devFunOnly = FALSE
         )
  if (requireNamespace("report", quietly = TRUE)) {
    fm2.4 |>
      report::report()
  }
  summary(fm2.4)
  anova(fm2.4)

  fm2.5 <-
    lme4::lmer(
           formula    = Pcv ~ dose * Drug + (1 | Region / Drug)
         , data       = ex125
         , REML       = TRUE
         , control    = lme4::lmerControl()
         , start      = NULL
         , verbose    = 0L
         , contrasts  = NULL
         , devFunOnly = FALSE
         )
  if (requireNamespace("report", quietly = TRUE)) {
    fm2.5 |>
      report::report()
  }
  summary(fm2.5)
  anova(fm2.5)
}

if (requireNamespace("lme4", quietly = TRUE) &&
    requireNamespace("lmerTest", quietly = TRUE)) {
  fm2.6 <-
    lmerTest::lmer(
           formula    = Pcv ~ dose * Drug + (1 | Region / Drug)
         , data       = ex125
         , REML       = FALSE
         , control    = lme4::lmerControl()
         , start      = NULL
         , verbose    = 0L
         , contrasts  = NULL
         , devFunOnly = FALSE
         )
  if (requireNamespace("report", quietly = TRUE)) {
    fm2.6 |>
      report::report()
  }
  summary(fm2.6)
  anova(fm2.6)

  fm2.7 <-
    lmerTest::lmer(
           formula    = Pcv ~ dose * Drug + (1 | Region / Drug)
         , data       = ex125
         , REML       = TRUE
         , control    = lme4::lmerControl()
         , start      = NULL
         , verbose    = 0L
         , contrasts  = NULL
         , devFunOnly = FALSE
         )
  if (requireNamespace("report", quietly = TRUE)) {
    fm2.7 |>
      report::report()
  }
  summary(fm2.7)
  anova(fm2.7)
}
# }

Run the code above in your browser using DataLab